==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/da.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Du kan ikke fjerne din egen læsetilladelse.",
    "Team folders" : "Teammapper",
    "Admin configured folders shared with everyone in a team" : "Admin konfigurerede mapper som er delt med alle i teamet",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Admin konfigurerede mapper der er delt med alle i et team.\n\nMapper kan konfigureres fra *Teammapper* i admin indtillingerne.\n\nEfter at en mappe er oprettet, så kan admin give adgan til mappen for et eller flere teams, kontrollere deres skrive-/delingsrettigheder og tildele en kvote til mappen.\nFra og med Hub 10/Nextcloud 31, skal admin være en del af teamet for at kunne tildele en teammappe til det.",
    "Unset" : "Fjern indstilling",
    "Denied (Inherited permission)" : "Afvist (nedarvet tilladelse)",
    "Allowed (Inherited permission)" : "Tilladt (nedarvet tilladelse)",
    "Denied" : "Afvist",
    "Allowed" : "Tilladt",
    "Access denied" : "Adgang nægtet",
    "Access allowed" : "Adgang tilladt",
    "Inherit permission" : "Nedarv tilladelse",
    "Deny" : "Afvis",
    "Allow" : "Tillad",
    "Group" : "Gruppe",
    "Team" : "Team",
    "Team folder" : "Teammappe",
    "Read" : "Læs",
    "Write" : "Skriv",
    "Create" : "Opret",
    "Delete" : "Slet",
    "Share" : "Del",
    "You" : "Dig",
    "Remove access rule" : "Fjern adgangsreglen",
    "Add advanced permission rule" : "Tilføj avanceret rettighedsregel",
    "Select a user or group" : "Vælg en bruger eller gruppe",
    "Open Team folder" : "Åben teammappe",
    "Permission denied. User does not have sufficient permissions." : "Adgang nægtet. Brugeren har ikke tilstrækkelige rettigheder.",
    "Unexpected status from server" : "Uventet status fra server",
    "List of Team folders." : "Liste over teammapper",
    "No Team folders yet" : "Endnu ingen teammapper",
    "Team folders will show up here" : "Teammapper vil blive vist her",
    "Add group" : "Tilføj gruppe",
    "Default" : "Standard",
    "Unlimited" : "Ubegrænset",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Er du sikker på, at du vil slette \"{folderName}\" og alle filer indeni? Denne handling kan ikke fortrydes",
    "Delete \"{folderName}\"?" : "Slet {folderName}?",
    "Team folder admin delegation" : "Teammappe admin delegering",
    "They will have access to all Team folders." : "De vil have adgang til alle teammapper",
    "They will only have access to Team folders for which they have advanced permissions." : "De vil kun have adgang til teammapper til hvilke de har avancerede rettigheder",
    "Group or team" : "Gruppe eller team",
    "Folder name" : "Mappenavn",
    "Quota" : "Kvote",
    "Advanced Permissions" : "Avancerede tilladelser",
    "Previous" : "Forrige",
    "Next" : "Næste",
    "User" : "ruger",
    "Unknown" : "Ukendt",
    "Users/groups that can manage" : "Brugere/grupper som kan administrere",
    "None" : "Ingen",
    "No other groups or teams available" : "Ingen andre grupper eller teams tilgængelige",
    "No other groups available" : "Ingen andre grupper tilgængelige",
    "{displayName} (team)" : "{displayName} (team)",
    "Add group or team" : "Tilføj gruppe eller team",
    "{size} used" : "{size} brugt",
    "You can not remove your own read permission." : "Du kan ikke fjerne din egen læserettighed.",
    "Group folders" : "Gruppemapper",
    "Admin configured folders shared with everyone in a group" : "Administratorkonfigurerede mapper deles med alle i en gruppe",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Admin konfigurede mapper der er delt med alle i en gruppe.\n\nMapper kan konfigureres fra *Gruppemapper* i adminindstillingerne.\n\nEfter at en mappe er oprettet, så kan admin give adgang til mappen for en eller flere grupper, kontrollere deres skrive-/delingsrettigheder og tildele en kvote til mappen.",
    "Group folder" : "Gruppemappe",
    "Open group folder" : "Åben gruppemappe",
    "List of group folders." : "Liste med gruppemapper",
    "No group folders yet" : "Endnu ingen gruppemapper",
    "Group folders will show up here" : "Gruppemapper vil blive vist her",
    "Group folder admin delegation" : "Gruppemapper administrator rettigheder ",
    "They will have access to all group folders." : "De vil have adgang til gruppemapper.",
    "They will only have access to group folders for which they have advanced permissions." : "De vil kun have adgang til gruppemapper til hvilke de har avancerede rettigheder.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Admin konfigurede mapper der er delt med alle i et team.\n\nMapper kan konfigureres fra *Teammapper* i adminindstillingerne.\n\nEfter at en mappe er oprettet, så kan admin give adgang til mappen for et eller flere teams, kontrollere deres skrive-/delingsrettigheder og tildele en kvote til mappen."
},
"nplurals=2; plural=(n != 1);");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/da.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Du kan ikke fjerne din egen læsetilladelse.",
    "Team folders" : "Teammapper",
    "Unset" : "Fjern indstilling",
    "Denied (Inherited permission)" : "Afvist (nedarvet tilladelse)",
    "Allowed (Inherited permission)" : "Tilladt (nedarvet tilladelse)",
    "Denied" : "Afvist",
    "Allowed" : "Tilladt",
    "Access denied" : "Adgang nægtet",
    "Access allowed" : "Adgang tilladt",
    "Inherit permission" : "Nedarv tilladelse",
    "Deny" : "Afvis",
    "Allow" : "Tillad",
    "Group" : "Gruppe",
    "Team" : "Team",
    "Team folder" : "Teammappe",
    "Read" : "Læs",
    "Write" : "Skriv",
    "Create" : "Opret",
    "Delete" : "Slet",
    "Share" : "Del",
    "You" : "Dig",
    "Remove access rule" : "Fjern adgangsreglen",
    "Add advanced permission rule" : "Tilføj avanceret rettighedsregel",
    "Select a user or group" : "Vælg en bruger eller gruppe",
    "Open Team folder" : "Åben teammappe",
    "Permission denied. User does not have sufficient permissions." : "Adgang nægtet. Brugeren har ikke tilstrækkelige rettigheder.",
    "Unexpected status from server" : "Uventet status fra server",
    "List of Team folders." : "Liste over teammapper",
    "No Team folders yet" : "Endnu ingen teammapper",
    "Team folders will show up here" : "Teammapper vil blive vist her",
    "Add group" : "Tilføj gruppe",
    "Default" : "Standard",
    "Unlimited" : "Ubegrænset",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Er du sikker på, at du vil slette \"{folderName}\" og alle filer indeni? Denne handling kan ikke fortrydes",
    "Delete \"{folderName}\"?" : "Slet {folderName}?",
    "Team folder admin delegation" : "Teammappe admin delegering",
    "They will have access to all Team folders." : "De vil have adgang til alle teammapper",
    "They will only have access to Team folders for which they have advanced permissions." : "De vil kun have adgang til teammapper til hvilke de har avancerede rettigheder",
    "Group or team" : "Gruppe eller team",
    "Folder name" : "Mappenavn",
    "Quota" : "Kvote",
    "Advanced Permissions" : "Avancerede tilladelser",
    "Previous" : "Forrige",
    "Next" : "Næste",
    "User" : "ruger",
    "Unknown" : "Ukendt",
    "Users/groups that can manage" : "Brugere/grupper som kan administrere",
    "None" : "Ingen",
    "No other groups or teams available" : "Ingen andre grupper eller teams tilgængelige",
    "No other groups available" : "Ingen andre grupper tilgængelige",
    "{displayName} (team)" : "{displayName} (team)",
    "Add group or team" : "Tilføj gruppe eller team",
    "{size} used" : "{size} brugt",
    "You can not remove your own read permission." : "Du kan ikke fjerne din egen læserettighed.",
    "Group folders" : "Gruppemapper",
    "Admin configured folders shared with everyone in a group" : "Administratorkonfigurerede mapper deles med alle i en gruppe",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Admin konfigurede mapper der er delt med alle i en gruppe.\n\nMapper kan konfigureres fra *Gruppemapper* i adminindstillingerne.\n\nEfter at en mappe er oprettet, så kan admin give adgang til mappen for en eller flere grupper, kontrollere deres skrive-/delingsrettigheder og tildele en kvote til mappen.",
    "Group folder" : "Gruppemappe",
    "Open group folder" : "Åben gruppemappe",
    "List of group folders." : "Liste med gruppemapper",
    "No group folders yet" : "Endnu ingen gruppemapper",
    "Group folders will show up here" : "Gruppemapper vil blive vist her",
    "Group folder admin delegation" : "Gruppemapper administrator rettigheder ",
    "They will have access to all group folders." : "De vil have adgang til gruppemapper.",
    "They will only have access to group folders for which they have advanced permissions." : "De vil kun have adgang til gruppemapper til hvilke de har avancerede rettigheder.",
    "Admin configured folders shared with everyone in a team" : "Admin konfigurerede mapper som er delt med alle i teamet",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Admin konfigurede mapper der er delt med alle i et team.\n\nMapper kan konfigureres fra *Teammapper* i adminindstillingerne.\n\nEfter at en mappe er oprettet, så kan admin give adgang til mappen for et eller flere teams, kontrollere deres skrive-/delingsrettigheder og tildele en kvote til mappen.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Admin konfigurerede mapper der er delt med alle i et team.\n\nMapper kan konfigureres fra *Teammapper* i admin indtillingerne.\n\nEfter at en mappe er oprettet, så kan admin give adgan til mappen for et eller flere teams, kontrollere deres skrive-/delingsrettigheder og tildele en kvote til mappen.\nFra og med Hub 10/Nextcloud 31, skal admin være en del af teamet for at kunne tildele en teammappe til det."
},
"nplurals=2; plural=(n != 1);");
